<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format">
	<xsl:param name="memId"/>
	<xsl:template match="profiler_result">
		<head>
			<META http-equiv="Content-Type" content="text/html; charset=US-ASCII"/>
			<title>Memory Summary</title>
			<link title="Style" type="text/css" rel="stylesheet" href="stylesheet.css"/>
		</head>
		<table width="100%">
			<tr>
				<td align="left">
					<a href="rules.html">Rules summary</a> - <a href="memories.html">Memories summary</a>
				</td>
				<td align="right">
				  <xsl:if test="@mode='noMemoryInfo'">
				    No memory counting information ! Check that the jrules-engine-profilingMode.jar 
				    is defined in your classpath before the jrules-engine.jar file.
			      </xsl:if>
				</td>
			</tr>
		</table>
		<hr size="1"/>
		<h2>Memory detail</h2>
		<xsl:apply-templates select="rule_mems/mem [@id=$memId]"/>
		<xsl:apply-templates select="mems/mem  [@id=$memId]"/>
	</xsl:template>
	<xsl:template match="mem">
		<table width="95%" cellspacing="2" cellpadding="2" border="0" class="details">
			<tr valign="top">
				<th>Id</th>
				<td>
					<xsl:value-of select="@id"/>
				</td>
			</tr>
			<tr>
				<th>Kind</th>
				<td>
					<xsl:value-of select="@kind"/>
				</td>
			</tr>
			<tr>
				<th>Impl class</th>
				<td>
					<xsl:value-of select="@class"/>
				</td>
			</tr>
			<tr>
				<th>Irl tests</th>
				<td>
					<xsl:value-of select="irl"/>
				</td>
			</tr>
			
			<xsl:if test="@kind='autoFinderMem'">
			  <tr>
				<th>Finder signature</th>
				<td>
					<xsl:value-of select="finder_signature"/>
				</td>
			  </tr>
			  <tr>
				<th>Updading-updated infos </th>
				<td>
					<xsl:value-of select="updating"/>, 
					<xsl:value-of select="updated"/>
				</td>
			  </tr>
			</xsl:if>
			
			<tr>
				<th>Rules</th>
				<td>
					<xsl:for-each select="linked_rules/rule">
						<a>
							<xsl:attribute name="href"><xsl:value-of select="text()"/>.html</xsl:attribute>
							<xsl:value-of select="text()"/>
						</a>
						<br/>
					</xsl:for-each>
				</td>
			</tr>
			<tr>
				<th>Parents</th>
				<td>
					<xsl:for-each select="parents/parent">
						<a>
							<xsl:attribute name="href"><xsl:value-of select="text()"/>.html</xsl:attribute>
							<xsl:value-of select="text()"/>
						</a>
						<br/>
					</xsl:for-each>
				</td>
			</tr>
			<tr>
				<th>Children</th>
				<td>
					<xsl:for-each select="children/child">
						<a>
							<xsl:attribute name="href"><xsl:value-of select="text()"/>.html</xsl:attribute>
							<xsl:value-of select="text()"/>
						</a>
						<br/>
					</xsl:for-each>
				</td>
			</tr>
			<xsl:if test="target_class">
				<tr>
					<th>Target class</th>
					<td>
						<xsl:value-of select="target_class"/>
					</td>
				</tr>
			</xsl:if>
			<xsl:if test="level">
				<tr>
					<th>Level</th>
					<td>
						<xsl:value-of select="level"/>
					</td>
				</tr>
			</xsl:if>

			<tr>
				<th>Average size</th>
				<td>
					<xsl:value-of select="size/average"/>
			        (<xsl:value-of select="size/min"/>,<xsl:value-of select="size/max"/>)
				</td>
			</tr>
			<xsl:if test="left_size">
				<tr>
					<th>Average left size</th>
					<td>
						<xsl:value-of select="left_size/average"/>
			        (<xsl:value-of select="left_size/min"/>,<xsl:value-of select="left_size/max"/>)
					</td>
				</tr>
			</xsl:if>
			<xsl:if test="right_size">
				<tr>
					<th>Average right size</th>
					<td>
						<xsl:value-of select="right_size/average"/>
			        (<xsl:value-of select="right_size/min"/>,<xsl:value-of select="right_size/max"/>)
					</td>
				</tr>
			</xsl:if>
			<tr>
				<th>Element tested</th>
				<td>
					<xsl:value-of select="mem_stat/tested"/>
					<a> (</a>
					<xsl:value-of select="./mem_stat/true_tested"/>
					<a>)</a>
				</td>
			</tr>
			<tr>
				<th>Element added</th>
				<td>
					<xsl:value-of select="mem_stat/added"/>
				</td>
			</tr>
			<tr>
				<th>Element removed</th>
				<td>
					<xsl:value-of select="mem_stat/removed"/>
				</td>
			</tr>
		</table>
		<h2>Statistics Per Class</h2>
		<table width="95%" cellspacing="2" cellpadding="3" border="0" class="details">
			<tr>
				<th>Class</th>
				<th>Event</th>
				<th>Elem tested</th>
				<th>Elem added</th>
				<th>Elem removed</th>
			</tr>
			<xsl:apply-templates select="detail_stat"/>
		</table>
	</xsl:template>
	<xsl:template match="class_stat">
		<tr>
			<td>
				<xsl:attribute name="rowspan"><xsl:value-of select="count( * ) + 1"/></xsl:attribute>
				<xsl:value-of select="@class"/>
			</td>
		</tr>
		<xsl:apply-templates select="insert|update|retract"/>
	</xsl:template>
	<xsl:template match="insert|update|retract">
		<tr>
			<td>
				<xsl:value-of select="name()"/>
			</td>
			<td>
				<xsl:value-of select="mem_stat/tested"/>
				<a> (</a>
				<xsl:value-of select="./mem_stat/true_tested"/>
				<a>)</a>
			</td>
			<td>
				<xsl:value-of select="mem_stat/added"/>
			</td>
			<td>
				<xsl:value-of select="mem_stat/removed"/>
			</td>
		</tr>
	</xsl:template>
</xsl:stylesheet>
