<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format">
	<xsl:param name="ruleName"/>
	<xsl:template match="profiler_result">
		<head>
			<META http-equiv="Content-Type" content="text/html; charset=US-ASCII"/>
			<title>Memory Summary</title>
			<link title="Style" type="text/css" rel="stylesheet" href="stylesheet.css"/>
		</head>
		<table width="100%">
			<tr>
				<td align="left">
					<a href="rules.html">Rules summary</a> - <a href="memories.html">Memories summary</a>
				</td>
				<td align="right">
				  <xsl:if test="@mode='noMemoryInfo'">
				    No memory counting information ! Check that the jrules-engine-profilingMode.jar 
				    is defined in your classpath before the jrules-engine.jar file.
			      </xsl:if>
				</td>
			</tr>
		</table>
		<hr size="1"/>
		<h2>Rule detail</h2>
		<xsl:apply-templates select="rules/rule [name=$ruleName]"/>
		<h2>Rule Memories detail</h2>
		<table width="95%" cellspacing="2" cellpadding="7" border="0" class="details">
			<tr valign="top">
				<th>Id</th>
				<th>Kind</th>
				<th>Parents</th>
				<th>Level</th>
				<th>Infos</th>
				<th>Size</th>
				<th>Tested</th>
				<th>Added</th>
				<th>Removed</th>
			</tr>
			<xsl:apply-templates select="mems/mem[linked_rules/rule=$ruleName][@kind='classMem']"/>
			<xsl:apply-templates select="mems/mem[linked_rules/rule=$ruleName][@kind='autoFinderMem']"/>
			<xsl:apply-templates select="mems/mem[linked_rules/rule=$ruleName][@kind='discMem']"/>
			<xsl:apply-templates select="mems/mem[linked_rules/rule=$ruleName][@kind='joinMem']"/>
			<xsl:apply-templates select="mems/mem[linked_rules/rule=$ruleName][@kind='leftMem']"/>
			<xsl:apply-templates select="rule_mems/mem[linked_rules/rule=$ruleName]"/>
		</table>
	</xsl:template>
	<xsl:template match="rule">
		<table width="95%" cellspacing="2" cellpadding="2" border="0" class="details">
			<tr valign="top">
				<th>Name</th>
				<td>
					<xsl:value-of select="name"/>
				</td>
			</tr>
			<tr>
				<th>IRL</th>
				<td>
					<pre>
						<xsl:value-of select="irl"/>
					</pre>
				</td>
			</tr>
			<tr>
				<th>Executed</th>
				<td>
					<xsl:value-of select="executed"/>
				</td>
			</tr>
			<tr>
				<th>Added</th>
				<td>
					<xsl:value-of select="added"/>
				</td>
			</tr>
			<tr>
				<th>Removed</th>
				<td>
					<xsl:value-of select="removed"/>
				</td>
			</tr>
			<tr>
				<th>Element tested</th>
				<td>
					<xsl:value-of select="mem_stat/tested"/>
					<a> (</a>
					<xsl:value-of select="./mem_stat/true_tested"/>
					<a>)</a>
				</td>
			</tr>
			<tr>
				<th>Element added</th>
				<td>
					<xsl:value-of select="mem_stat/added"/>
				</td>
			</tr>
			<tr>
				<th>Element removed</th>
				<td>
					<xsl:value-of select="mem_stat/removed"/>
				</td>
			</tr>
		</table>
	</xsl:template>
	<xsl:template match="mem">
		<tr valign="top" class="Pass">
			<td>
				<a>
					<xsl:attribute name="href"><xsl:value-of select="@id"/>.html</xsl:attribute>
					<xsl:value-of select="@id"/>
				</a>
			</td>
			<td>
				<xsl:value-of select="@kind"/>
			</td>

			<td>
					<xsl:for-each select="parents/parent">
						<a>
							<xsl:attribute name="href"><xsl:value-of select="text()"/>.html</xsl:attribute>
							<xsl:value-of select="text()"/>
						</a>
						<br/>
					</xsl:for-each>
			</td>
			
			<td>
				<xsl:value-of select="level"/>
			</td>
			<td>
				<xsl:value-of select="target_class"/>
				<xsl:value-of select="irl"/>
			</td>
			<td>
				<xsl:value-of select="size/average"/>
			        (<xsl:value-of select="size/min"/>,<xsl:value-of select="size/max"/>)
			</td>
			<td>
				<xsl:value-of select="./mem_stat/tested"/>
				<a> (</a>
				<xsl:value-of select="./mem_stat/true_tested"/>
				<a>)</a>
			</td>
			<td>
				<xsl:value-of select="./mem_stat/added"/>
			</td>
			<td>
				<xsl:value-of select="./mem_stat/removed"/>
			</td>
		</tr>
	</xsl:template>
</xsl:stylesheet>
